@@ -15,8 +15,9 @@ from .builtins import (
     dict,
     set,
     tuple,
+    sorted,
 )
-from .functools import reduce, lru_cache, cached_property
+from .functools import reduce, lru_cache, cache, cached_property
 from .contextlib import closing, contextmanager, nullcontext, ExitStack
 from .itertools import (
     accumulate,
@@ -33,7 +34,7 @@ from .itertools import (
 )
 from .asynctools import borrow, scoped_iter
 
-__version__ = "1.1.3"
+__version__ = "3.9.0"
 
 __all__ = [
     "anext",
@@ -51,9 +52,11 @@ __all__ = [
     "dict",
     "set",
     "tuple",
+    "sorted",
     # functools
     "reduce",
     "lru_cache",
+    "cache",
     "cached_property",
     # contextlib
     "closing",
