@@ -157,9 +157,7 @@ async def ayield_exactly(count: int):
 
 
 @sync
-@pytest.mark.parametrize(
-    "slicing", ((0,), (5,), (0, 20, 3), (5, 0, 1), (3, 50, 4)),
-)
+@pytest.mark.parametrize("slicing", ((0,), (5,), (0, 20, 3), (5, 0, 1), (3, 50, 4)))
 async def test_islice_exact(slicing):
     """`isclice` consumes exactly as many items as needed"""
     boundary = slice(*slicing) if len(slicing) > 1 else slice(0, slicing[0])
